==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pt_BR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartilhamento de servidor para servidor não está habilitado no servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticação com o compartilhamento remoto, a senha deve estar errada",
    "Storage not valid" : "Armazenamento não válido",
    "Couldn't add remote share" : "Não foi possível adicionar compartilhamento remoto",
    "Shared with you" : "Compartilhado com você",
    "Shared with others" : "Compartilhado com outros",
    "Shared by link" : "Compartilhado por link",
    "Nothing shared with you yet" : "Nada compartilhado com você até agora",
    "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você são mostrados aqui",
    "Nothing shared yet" : "Nada compartilhado até agora",
    "Files and folders you share will show up here" : "Arquivos e pastas que você compartilha são mostrados aqui",
    "No shared links" : "Nenhum link compartilhado",
    "Files and folders you share by link will show up here" : "Arquivos e pastas que você compartilha com link são mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Você quer adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "You can upload into this folder" : "Você não pode enviar arquivos para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nenhuma instalação ownCloud (7 ou superior) foi encontrada em {remote}",
    "Invalid ownCloud url" : "Url invalida para ownCloud",
    "Shared by" : "Compartilhado por",
    "Sharing" : "Compartilhamento",
    "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
    "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhada a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhada publicamente foi <strong>baixado</strong>",
    "You received a new remote share %2$s from %1$s" : "Você recebeu um novo conpartilhamento remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Você recebeu um novo compartilhamento remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou o compartilhamento remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s declinou o compartilhamento remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s não compartilhados %2$s de você",
    "Public shared folder %1$s was downloaded" : "A pasta %1$s compartilhada publicamente foi baixada",
    "Public shared file %1$s was downloaded" : "O arquivo %1$s compartilhado publicamente foi baixado",
    "You shared %1$s with %2$s" : "Você compartilhou %1$s com %2$s",
    "You shared %1$s with group %2$s" : "Você compartilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartilhado %1$s com %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartilhado %1$s com o grupo %3$s",
    "%2$s shared %1$s via link" : "%2$s compartilhado via link %1$s",
    "%2$s shared %1$s with you" : "%2$s compartilhou %1$s com você",
    "You shared %1$s via link" : "Você compartilhou %1$s via link",
    "Downloaded via public link" : "Baixar via link público",
    "Shared with %2$s" : "Compartilhado com %2$s",
    "Shared with group %2$s" : "Compartilhado com o grupo %2$s",
    "Shared with %3$s by %2$s" : "Compartilhado com %3$s por %2$s",
    "Shared with group %3$s by %2$s" : "Compartilhado com o grupo %3$s por %2$s",
    "Shared via link by %2$s" : "Compartilhado via link por %2$s",
    "Shared by %2$s" : "Compartilhado por %2$s",
    "Shared via public link" : "Compartilhado via link público",
    "Shares" : "Compartilhamentos",
    "You received %2$s as a remote share from %1$s" : "Você recebeu %2$s como um compartilhamento remoto de %1$s",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu #ownCloud Nuvem Federados ID, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Compartilhe comigo através do meu #ownCloud Nuvem Federados ID",
    "This share is password-protected" : "Este compartilhamento esta protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "Share time" : "Tempo de compartilhamento",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, este link parece não mais  funcionar.",
    "Reasons might be:" : "As razões podem ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more info, please ask the person who sent this link." : "Para mais informações, por favor, pergunte a pessoa que enviou este link.",
    "Add to your ownCloud" : "Adiconar ao seu ownCloud",
    "Download" : "Baixar",
    "Download %s" : "Baixar %s",
    "Direct link" : "Link direto",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Conglomerada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários nesse servidor recebam compartilhamentos de outros servidores",
    "Federated Cloud" : "Nuvem Conglomerada",
    "Your Federated Cloud ID:" : "Seu Federados Nuvem ID:",
    "Share it:" : "Compartilhe:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via ownCloud" : "Compartilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pt_BR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartilhamento de servidor para servidor não está habilitado no servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não permitido para criar um compartilhamento associado com o mesmo servidor do usuário",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticação com o compartilhamento remoto, a senha deve estar errada",
    "Storage not valid" : "Armazenamento não válido",
    "Couldn't add remote share" : "Não foi possível adicionar compartilhamento remoto",
    "Shared with you" : "Compartilhado com você",
    "Shared with others" : "Compartilhado com outros",
    "Shared by link" : "Compartilhado por link",
    "Federated sharing" : "Compartilhamento associado",
    "Nothing shared with you yet" : "Nada compartilhado com você até agora",
    "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você são mostrados aqui",
    "Nothing shared yet" : "Nada compartilhado até agora",
    "Files and folders you share will show up here" : "Arquivos e pastas que você compartilha são mostrados aqui",
    "No shared links" : "Nenhum link compartilhado",
    "Files and folders you share by link will show up here" : "Arquivos e pastas que você compartilha com link são mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Você quer adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "You can upload into this folder" : "Você não pode enviar arquivos para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nenhuma instalação ownCloud (7 ou superior) foi encontrada em {remote}",
    "Invalid ownCloud url" : "Url invalida para ownCloud",
    "Shared by" : "Compartilhado por",
    "Sharing" : "Compartilhamento",
    "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
    "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhado publicamente foi <strong>baixado</strong>",
    "You received a new remote share %2$s from %1$s" : "Você recebeu um novo conpartilhamento remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Você recebeu um novo compartilhamento remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou o compartilhamento remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s declinou o compartilhamento remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s não compartilhados %2$s de você",
    "Public shared folder %1$s was downloaded" : "A pasta %1$s compartilhada publicamente foi baixada",
    "Public shared file %1$s was downloaded" : "O arquivo %1$s compartilhado publicamente foi baixado",
    "You shared %1$s with %2$s" : "Você compartilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartilhado %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removido o compartilhamento de %3$s para %1$s",
    "You shared %1$s with group %2$s" : "Você compartilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartilhado %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removido o compartilhamento do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s compartilhado via link %1$s",
    "You shared %1$s via link" : "Você compartilhou %1$s via link",
    "You removed the public link for %1$s" : "Você removeu o link público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu o link público de %1$s",
    "Your public link for %1$s expired" : "O seu link público para %1$s expirou",
    "The public link of %2$s for %1$s expired" : "O link público de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s compartilhou %1$s com você",
    "%2$s removed the share for %1$s" : "%2$s removeu o compartilhamento para %1$s",
    "Downloaded via public link" : "Baixar via link público",
    "Shared with %2$s" : "Compartilhado com %2$s",
    "Shared with %3$s by %2$s" : "Compartilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Removido compartilhamento para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu o compartilhamento para %3$s",
    "Shared with group %2$s" : "Compartilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Removido compartilhamento para o grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removido compartilhamento do grupo %3$s",
    "Shared via link by %2$s" : "Compartilhado via link por %2$s",
    "Shared via public link" : "Compartilhado via link público",
    "Removed public link" : "Removido o link público",
    "%2$s removed public link" : "%2$s removeu o link público",
    "Public link expired" : "O link público expirou",
    "Public link of %2$s expired" : "O link público de %2$s expirou",
    "Shared by %2$s" : "Compartilhado por %2$s",
    "Shares" : "Compartilhamentos",
    "You received \"/%2$s\" as a remote share from %1$s" : "Você recebeu \"/%2$s\" como um compartilhamento remoto de %1$s",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Associada, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Compartilhe comigo através do meu #ownCloud Nuvem ID Associada",
    "This share is password-protected" : "Este compartilhamento esta protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "Share time" : "Data compartilhado",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, este link parece não mais  funcionar.",
    "Reasons might be:" : "As razões podem ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more info, please ask the person who sent this link." : "Para mais informações, por favor, pergunte a pessoa que enviou este link.",
    "Add to your ownCloud" : "Adiconar ao seu ownCloud",
    "Download" : "Baixar",
    "Download %s" : "Baixar %s",
    "Direct link" : "Link direto",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Associada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir que os usuários deste servidor enviem compartilhamentos para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os usuários nesse servidor recebam compartilhamentos de outros servidores",
    "Federated Cloud" : "Nuvem Associada",
    "Your Federated Cloud ID:" : "Sua ID na Nuvem Associada:",
    "Share it:" : "Compartilhe:",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via ownCloud" : "Compartilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n > 1);");
